@@ -15,10 +15,6 @@ def subdir_suffix(s: str) -> str:
 
 def main():
     """Main function"""
-    # disallow usage on non-Windows platforms
-    if sys.platform != 'win32':
-        raise EnvironmentError('delvewheel is supported on Windows only')
-
     # parse arguments
     parser = argparse.ArgumentParser(description='Self-contained wheels for Windows')
     kwargs = {'dest': 'command'}
@@ -33,14 +29,14 @@ def main():
     parser_needed = subparsers.add_parser('needed', help=parser_needed_description, description=parser_needed_description)
     for subparser in (parser_show, parser_repair):
         subparser.add_argument('wheel', nargs='+', help='wheel(s) to show or repair')
-        subparser.add_argument('--add-path', default='', metavar='PATHS', help='extra paths(s) to search for DLLs, semicolon-delimited')
-        subparser.add_argument('--add-dll', default='', metavar='DLLS', help='force inclusion of DLL name(s), semicolon-delimited')
-        subparser.add_argument('--no-dll', default='', metavar='DLLS', help='force exclusion of DLL name(s), semicolon-delimited')
+        subparser.add_argument('--add-path', default='', metavar='PATHS', help=f'additional path(s) to search for DLLs, {os.pathsep!r}-delimited')
+        subparser.add_argument('--add-dll', default='', metavar='DLLS', help=f'force inclusion of DLL name(s), {os.pathsep!r}-delimited')
+        subparser.add_argument('--no-dll', default='', metavar='DLLS', help=f'force exclusion of DLL name(s), {os.pathsep!r}-delimited')
         subparser.add_argument('--ignore-in-wheel', action='store_true', help="don't search for or vendor in DLLs that are already in the wheel")
         subparser.add_argument('-v', action='count', default=0, help='verbose mode')
         subparser.add_argument('--extract-dir', help=argparse.SUPPRESS)
     parser_repair.add_argument('-w', '--wheel-dir', dest='target', default='wheelhouse', help='directory to write repaired wheel')
-    parser_repair.add_argument('--no-mangle', default='', metavar='DLLS', help='DLL names(s) not to mangle, semicolon-delimited')
+    parser_repair.add_argument('--no-mangle', default='', metavar='DLLS', help=f'DLL names(s) not to mangle, {os.pathsep!r}-delimited')
     parser_repair.add_argument('--no-mangle-all', action='store_true', help="don't mangle any DLL names")
     parser_repair.add_argument('-L', '--lib-sdir', default='.libs', type=subdir_suffix, help='directory suffix in package to store vendored DLLs (default .libs)')
     parser_needed.add_argument('file', help='path to a DLL or PYD file')
@@ -50,9 +46,9 @@ def main():
 
     # handle command
     if args.command in ('show', 'repair'):
-        add_paths = set(os.path.abspath(path) for path in args.add_path.split(';') if path)
-        add_dlls = set(dll_name.lower() for dll_name in args.add_dll.split(';') if dll_name)
-        no_dlls = set(dll_name.lower() for dll_name in args.no_dll.split(';') if dll_name)
+        add_paths = set(os.path.abspath(path) for path in args.add_path.split(os.pathsep) if path)
+        add_dlls = set(dll_name.lower() for dll_name in args.add_dll.split(os.pathsep) if dll_name)
+        no_dlls = set(dll_name.lower() for dll_name in args.no_dll.split(os.pathsep) if dll_name)
 
         intersection = add_dlls & no_dlls
         if intersection:
@@ -66,7 +62,7 @@ def main():
             if args.command == 'show':
                 wr.show()
             else:  # args.command == 'repair'
-                no_mangles = set(dll_name.lower() for dll_name in args.no_mangle.split(';') if dll_name)
+                no_mangles = set(dll_name.lower() for dll_name in args.no_mangle.split(os.pathsep) if dll_name)
                 wr.repair(args.target, no_mangles, args.no_mangle_all, args.lib_sdir)
     else:  # args.command == 'needed'
         for dll_name in patch_dll.get_direct_needed(args.file):
